@@ -1,6 +1,6 @@
 {
     'name': "Comunitats Energètiques customizations",
-    'version': '12.0.0.0.7',
+    'version': '12.0.0.0.9',
     'depends': [
         'base_rest_base_structure',
         'cooperator_website',
@@ -41,6 +41,8 @@
         'views/menus.xml',
         'views/res_users.xml',
         'views/cm_place.xml',
+        'data/mail_template_data.xml',
+        'data/mail_template_update_data.xml'
     ],
     'installable': True,
     'application': True,
