@@ -24,3 +24,15 @@ class SubscriptionRequest(models.Model):
                 raise UserError(_("You must set a cooperator journal on you company."))
 
         return j
+
+    def get_required_field(self):
+        required_fields =  super(SubscriptionRequest,self).get_required_field()
+        if 'iban' in required_fields: required_fields.remove('iban')
+        return required_fields
+
+    @api.model
+    def create(self, vals):
+        if vals:
+            vals['skip_iban_control'] = True
+        subscription_request = super(SubscriptionRequest, self).create(vals)
+        return subscription_request
